@@ -152,21 +152,19 @@ test_that("can parse subsecond precision", {
   )
 })
 
-test_that("parsing to a lower precision ignores higher precision info", {
+test_that("parsing works if `precision` uses a default that doesn't attempt to capture all the info", {
+  # Uses %Y-%m-%d
   x <- "2019-01-01 01:00:00"
-  y <- "2019-01-01 01:00:00.12345"
-
   expect_identical(
     naive_time_parse(x, precision = "day"),
     as_naive_time(year_month_day(2019, 1, 1))
   )
+
+  # Uses %Y-%m-%d %H:%M
+  x <- "2019-01-01 01:00:59"
   expect_identical(
-    naive_time_parse(y, precision = "second"),
-    as_naive_time(year_month_day(2019, 1, 1, 1, 0, 0))
-  )
-  expect_identical(
-    naive_time_parse(y, precision = "millisecond"),
-    as_naive_time(year_month_day(2019, 1, 1, 1, 0, 0, 123, subsecond_precision = "millisecond"))
+    naive_time_parse(x, precision = "minute"),
+    as_naive_time(year_month_day(2019, 1, 1, 1, 0))
   )
 })
 
@@ -182,9 +180,11 @@ test_that("parsing day components with second precision uses midnight as time",
 test_that("cannot parse invalid dates", {
   x <- "2019-02-31"
 
-  expect_identical(
-    expect_warning(naive_time_parse(x, precision = "day")),
-    naive_days(NA)
+  expect_warning(
+    expect_identical(
+      naive_time_parse(x, precision = "day"),
+      naive_days(NA)
+    )
   )
 
   expect_snapshot(naive_time_parse(x, precision = "day"))
@@ -203,9 +203,11 @@ test_that("can parse with multiple formats", {
 test_that("failure to parse results in NA", {
   x <- "2019-01-oh"
 
-  expect_identical(
-    expect_warning(naive_time_parse(x, format = "%Y-%m-%d", precision = "day")),
-    naive_days(NA)
+  expect_warning(
+    expect_identical(
+      naive_time_parse(x, format = "%Y-%m-%d", precision = "day"),
+      naive_days(NA)
+    )
   )
 })
 
@@ -257,9 +259,11 @@ test_that("%z is completely ignored, but is required to be parsed correctly if s
     naive_time_parse(x, format = "%Y-%m-%d %H:%M:%S%z"),
     as_naive_time(year_month_day(2019, 1, 1, 0, 0, 0))
   )
-  expect_identical(
-    expect_warning(naive_time_parse(y, format = "%Y-%m-%d %H:%M:%S%z")),
-    naive_seconds(NA)
+  expect_warning(
+    expect_identical(
+      naive_time_parse(y, format = "%Y-%m-%d %H:%M:%S%z"),
+      naive_seconds(NA)
+    )
   )
 })
 
@@ -272,7 +276,7 @@ test_that("%Z is completely ignored", {
   )
 })
 
-test_that("parsing rounds parsed components more precise than the resulting container (#207)", {
+test_that("parsing rounds parsed components more precise than the resulting container (#207) (#230) (undocumented)", {
   expect_identical(
     naive_time_parse("2019-12-31 11", format = "%Y-%m-%d %H", precision = "day"),
     as_naive_time(year_month_day(2019, 12, 31))
@@ -289,7 +293,7 @@ test_that("parsing rounds parsed components more precise than the resulting cont
   )
 })
 
-test_that("parsing rounds parsed subsecond components more precise than the resulting container (#207)", {
+test_that("parsing rounds parsed subsecond components more precise than the resulting container (#207) (#230) (undocumented)", {
   # Default N for milliseconds is 6, so `%6S` (2 hour seconds, 1 for decimal, 3 for subseconds)
   expect_identical(
     naive_time_parse("2019-01-01 01:01:01.1238", format = "%Y-%m-%d %H:%M:%S", precision = "millisecond"),
@@ -303,6 +307,16 @@ test_that("parsing rounds parsed subsecond components more precise than the resu
   )
 })
 
+test_that("parsing fails when undocumented rounding behavior would result in invalid 60 second component (#230) (undocumented)", {
+  expect_warning(
+    expect_identical(
+      naive_time_parse("2019-01-01 01:01:59.550", format = "%Y-%m-%d %H:%M:%6S", precision = "second"),
+      as_naive_time(year_month_day(NA, NA, NA, NA, NA, NA))
+    ),
+    class = "clock_warning_parse_failures"
+  )
+})
+
 # ------------------------------------------------------------------------------
 # format()
 
